import type { CartaExtension } from 'carta-md';
interface CodeExtensionOptions {
    /**
     * Default language when none is provided.
     */
    defaultLanguage?: string;
    /**
     * Whether to autodetect a language when none is provided.
     * Overwritten by `defaultLanguage`.
     */
    autoDetect?: string;
    /**
     * Line numbering.
     * @defaults false.
     */
    lineNumbering?: boolean;
    /**
     * Options for custom syntax highlighting.
     */
    customHighlight?: {
        /**
         * Custom highlight function. Beware that you'll have to provide your own styles.
         * This function needs to convert a string of code into html.
         */
        highlighter: (code: string, lang: string) => string | Promise<string>;
        /**
         * The language tag found immediately after the code block opening marker is
         * appended to this to form the class attribute added to the `<code>` element.
         */
        langPrefix: string;
    };
}
/**
 * Carta code highlighting plugin. Themes available on [GitHub](https://github.com/speed-highlight/core/tree/main/dist/themes).
 */
export declare const code: (options?: CodeExtensionOptions) => CartaExtension;
export {};
